@@ -1,7 +1,13 @@
-from pythonish_validator.common import validate
+from pythonish_validator.common import validate, Validator
 
 
 def test_repr_one():
+    validator = Validator(str)
+
+    validator.is_valid("asd")
+    validator.is_valid([1])
+    assert validator.repr_errors() == ["[[1]]"]
+
     validator = validate({
         'name': str,
         'age': int,
